/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.client.internal.UserClient");

dojo.require("com.ibm.rational.report.web.core.client.internal.SessionManager");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
dojo.require("com.ibm.team.process.web.client.projectarea");

var SessionManager			= com.ibm.rational.report.web.core.client.internal.SessionManager;
var session					= com.ibm.team.repository.web.client.session;
var ServiceRequest 			= com.ibm.team.repository.web.transport.ServiceRequest;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var TeamServerClient 		= com.ibm.team.repository.web.transport.TeamServerClient;

/**
 * Manages user REST service calls.
 */
com.ibm.rational.report.web.core.client.internal.UserClient = {

	SERVICE_URI: "com.ibm.rational.user.common.IUserRestService",
	
	getAuthenticatedUser: function(responseHandler) {
		this._invokeUserService(responseHandler, "getAuthenticatedUser", null);
	},
	
	getAdminUser: function(responseHandler) {
		this._invokeUserService(responseHandler, "getAdminUser", null);
	},
	
	getGuestUser: function(responseHandler) {
		this._invokeUserService(responseHandler, "getGuestUser", null);
	},
	
	getIsProjectLead: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getIsProjectLead", args);
	},
	
	getIsAdmin: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getIsAdmin", args);
	},
	
	getAdminUsers: function(responseHandler) {
		this._invokeUserService(responseHandler, "getAdminUsers");
	},
	
	getIsReadOnlyUserRegistry: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getIsReadOnlyUserRegistry", args);
	},
		
	getAllUsers: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getAllUsers", args);
	},
	
	getAllUserAttributes: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getAllUserAttributes", args);
	},
	
	getUsers: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getUsers", args);
	},
	
	getUser: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getUser", args);
	},
	
	postNewUser: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postNewUser", args);
	},

	postDeleteUser: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postDeleteUser", args);
	},
	
	postNewContributor: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postNewContributor", args);
	},
	
	postDeleteContributor: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postDeleteContributor", args);
	},
	
	postDeleteContributors: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postDeleteContributors", args);
	},
		
	getUserAttributes: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getUserAttributes", args);
	},
	
	postNewContributors: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postNewContributors", args);
	},
	
	postUpdateUserAttributes: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postUpdateUserAttributes", args);
	},
	
	getAllGroups: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getAllGroups", null);
	},
	
	getGroup: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getGroup", args);
	},
	
	postNewGroup: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postNewGroup", args);
	},
	
	postUpdateGroup: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postUpdateGroup", args);
	},
	
	postDeleteGroup: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postDeleteGroup", args);
	},

	getValidatePassword: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "getValidatePassword", args);
	},
	
	postRefreshUserRegistry: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postRefreshUserRegistry", args);
	},
	
	postUpdateUserCredential: function(responseHandler, args) {
		this._invokeUserService(responseHandler, "postUpdateUserCredential", args);
	},
	
	/**
	 * Invokes the requested method on the user REST service.
	 */
	_invokeUserService: function(responseHandler, method, args) {
		if (arguments.length == 2) {
			var serviceRequest= new com.ibm.team.repository.web.transport.ServiceRequest(
					this.SERVICE_URI,
					method);
		} else {
			serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.SERVICE_URI,
					method,
					args);
		}
		com.ibm.team.repository.web.transport.TeamServerClient.invokeService(
				serviceRequest,
				responseHandler);
		SessionManager.resetTimeOut();
	}
};

})();